=========================================
``psyclone.psyir.tools.dependency_tools``
=========================================

.. automodule:: psyclone.psyir.tools.dependency_tools

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.tools.dependency_tools
